@file:AnAnnotation

package cases

@Suppress("Unused")
class Test

@Target(AnnotationTarget.FILE, AnnotationTarget.FUNCTION)
annotation class AnAnnotation
